require 'securerandom' # needed for per Thread uuid generation

module Testcloud
  # Support extends the Testcloud module itself
  # in order to add global methods that can be accessible by all projects that
  # use the Testcloud namespace
  class << self

    FALLBACK_ENV = 'development'.freeze

    # The preferred default environment is TESTCLOUD_ENV.
    # The first fallback is to RAILS_ENV then RACK_ENV (for rails and rack apps), when nothing is set don't allow
    # a nil env so we set it to FALLBACK_ENV
    require 'active_support/string_inquirer'

    def env
      @_env ||= begin
        default_env = ENV['TESTCLOUD_ENV'] || ENV['RAILS_ENV'] || ENV['RACK_ENV'] || FALLBACK_ENV
        ActiveSupport::StringInquirer.new(default_env)
      end
    end

    def env=(environment)
      @_env = ActiveSupport::StringInquirer.new(environment)
    end

    # We want to be able to uniquely identify separate threads
    # but we should probably make this UUIDv5 for more assurance of uniqueness
    def uuid=(uuid_value)
      Thread.current[:uuid] = uuid_value
    end

    def uuid
      Thread.current[:uuid] ||= SecureRandom.uuid
    end

  end # self
end
